==> seedsui-react-5.7.93.tgz: package/lib/Location/Main/utils/searchNearby.js <==
import formatPoint from "./formatPoint";
import gcjToBdPoint from "./gcjToBdPoint";
import pointToBdPoint from "./pointToBdPoint";

// 搜索附近, keyword:搜索关键词
function searchNearby(keyword, _ref) {
  var map = _ref.map,
    type = _ref.type,
    point = _ref.point,
    _ref$radius = _ref.radius,
    radius = _ref$radius === void 0 ? 1000 : _ref$radius;
  return new Promise(function (resolve) {
    // 创建本地搜索对象
    var local = new window.BMap.LocalSearch(map, {
      pageCapacity: 100,
      onSearchComplete: function onSearchComplete(results) {
        if (local.getStatus() === window.BMAP_STATUS_SUCCESS) {
          var res = [];
          for (var i = 0; i < results.getCurrentNumPois(); i++) {
            var _item$point, _item$point2;
            var item = results.getPoi(i);
            // 补充value,latitude,longitude
            item.value = (item === null || item === void 0 ? void 0 : item.address) || '';
            item.longitude = (item === null || item === void 0 ? void 0 : (_item$point = item.point) === null || _item$point === void 0 ? void 0 : _item$point.lng) || '';
            item.latitude = (item === null || item === void 0 ? void 0 : (_item$point2 = item.point) === null || _item$point2 === void 0 ? void 0 : _item$point2.lat) || '';
            res.push(item);
          }
          resolve(res);
        } else {
          resolve(null);
        }
      }
    });

    // 传入点: 经过实验，百度地图searchNearby只根据当前显示的区域搜索，传point没有任何变化（所以不要传，传了也白传）
    if (point) {
      // eslint-disable-next-line
      point = formatPoint(point);
      if (type === 'gcj02') {
        // eslint-disable-next-line
        point = gcjToBdPoint(point);
      } else {
        // eslint-disable-next-line
        point = pointToBdPoint(point);
      }
    }

    // 如果没有传入点, 则默认取中心点
    if (!point) {
      // eslint-disable-next-line
      point = map.getCenter(); // 搜索中心点坐标
    }

    local.searchNearby(keyword, point, radius);
  });
}
export default searchNearby;

==> seedsui-react-5.8.44.tgz: package/lib/Location/Main/utils/searchNearby.js <==
import formatPoint from "./formatPoint";
import gcjToBdPoint from "./gcjToBdPoint";
import pointToBdPoint from "./pointToBdPoint";

// 搜索附近, keyword:搜索关键词
function searchNearby(keyword, _ref) {
  var map = _ref.map,
    type = _ref.type,
    point = _ref.point,
    _ref$radius = _ref.radius,
    radius = _ref$radius === void 0 ? 1000 : _ref$radius;
  return new Promise(function (resolve) {
    // 创建本地搜索对象
    var local = new window.BMap.LocalSearch(map, {
      pageCapacity: 100,
      onSearchComplete: function onSearchComplete(results) {
        if (local.getStatus() === window.BMAP_STATUS_SUCCESS) {
          var res = [];
          for (var i = 0; i < results.getCurrentNumPois(); i++) {
            var _item$point, _item$point2;
            var item = results.getPoi(i);
            // 补充value,latitude,longitude
            item.value = (item === null || item === void 0 ? void 0 : item.address) || '';
            item.longitude = (item === null || item === void 0 || (_item$point = item.point) === null || _item$point === void 0 ? void 0 : _item$point.lng) || '';
            item.latitude = (item === null || item === void 0 || (_item$point2 = item.point) === null || _item$point2 === void 0 ? void 0 : _item$point2.lat) || '';
            res.push(item);
          }
          resolve(res);
        } else {
          resolve(null);
        }
      }
    });

    // 传入点: 经过实验，百度地图searchNearby只根据当前显示的区域搜索，传point没有任何变化（所以不要传，传了也白传）
    if (point) {
      // eslint-disable-next-line
      point = formatPoint(point);
      if (type === 'gcj02') {
        // eslint-disable-next-line
        point = gcjToBdPoint(point);
      } else {
        // eslint-disable-next-line
        point = pointToBdPoint(point);
      }
    }

    // 如果没有传入点, 则默认取中心点
    if (!point) {
      // eslint-disable-next-line
      point = map.getCenter(); // 搜索中心点坐标
    }
    local.searchNearby(keyword, point, radius);
  });
}
export default searchNearby;
